@@ -1,12 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mise" "0.3.1"
+(define-package "mise" "20250910.1021"
   "Support for `mise' cli."
   '((emacs      "29.1")
-    (inheritenv "0.2")
-    (dash       "2.19.1"))
+    (inheritenv "0.2"))
   :url "https://github.com/eki3z/mise.el"
-  :commit "2ba633b84c5d678ef128901c443ee43f6052d3de"
-  :revdesc "2ba633b84c5d"
+  :commit "60ef63466d07417a9ef956af363baae39c9ddf34"
+  :revdesc "60ef63466d07"
   :keywords '("tools" "processes")
   :authors '(("Eki Zhang" . "liuyinz95@gmail.com"))
   :maintainers '(("Eki Zhang" . "liuyinz95@gmail.com")))
